@@ -208,7 +208,6 @@ def run_pca_ancestry_analysis(
     """
     :param mt: variants usable for PCA analysis, combined with samples
         with known populations (HGDP, 1KG, etc)
-    :param tmp_bucket: bucket path to write checkpoints
     :param sample_to_drop_ht: table with samples to drop based on
         previous relatedness analysis. With a `rank` row field
     :param n_pcs: maximum number of principal components
@@ -234,10 +233,19 @@ def run_pca_ancestry_analysis(
     # number of samples
     samples_to_drop_num = 0 if sample_to_drop_ht is None else sample_to_drop_ht.count()
     n_pcs = min(n_pcs, mt.cols().count() - samples_to_drop_num)
+    
+    logger.info(f'mt.s: {mt.s.collect()}')
+    if sample_to_drop_ht:
+        logger.info(f'sample_to_drop_ht.s: {sample_to_drop_ht.s.collect()}')
+    
     eigenvalues, scores_ht, loadings_ht = run_pca_with_relateds(
         mt, sample_to_drop_ht, n_pcs=n_pcs
     )
 
+    logger.info(f'scores_ht.s: {scores_ht.s.collect()}')
+    logger.info(f'loadings_ht.s: {loadings_ht.s.collect()}')
+    logger.info(f'eigenvalues: {eigenvalues}')
+
     hl.Table.from_pandas(pd.DataFrame(eigenvalues)).export(out_eigenvalues_path)
     loadings_ht.write(out_loadings_ht_path, overwrite=True)
     scores_ht.write(out_scores_ht_path, overwrite=True)
